#==================================================
# Check-live365 - Check status of a Live365 stream
#==================================================
# NOTE: YOU MUST MODIFY THIS CODE FOR USE ON YOUR STREAM!
#
# Specifically, the variables $SMTP_SERVER, $ALERT_EMAIL_ADDR,
# $LIVE365_STATION_IP and $LIVE365_STATION_PORT must be set to appropriate
# values for your stream.
#
# THIS CODE WILL NOT WORK WITHOUT MODIFICATION!
#
# Whew... now I feel better. ;-)
#
# The changes are trivial and should be obvious.  If you have any questions
# about how to modify the code drop me an email at tim@frontierdigital.com.
#
# T.
#
# ----------------
# Run Time Options
# -a - Send Alert Email
# -w - HTML output
# -f filename - output filename
#
# June 26, 2001 - T. Carter (tim@frontierdigital.com)
#	- Clean-up the code a bit to make it easier for others to modify.
#
#==================================================

# ----------------
# Perl modules required
#
use Net::Telnet;
require Mail::Sender;	# Not part of standard PERL install - see http://search.cpan.org
use Getopt::Std;

# ----------------
# Globals
#
$PGM_NAME = "CheckLive365";
$PGM_VERS = "v1.0";
$SMTP_SERVER = 'mail.domain.com';		# PLEASE DONT USE THIS SERVER, USE YOUR OWN HERE
$ALERT_EMAIL_ADDR = 'user@domain.com';		# This is the from and to address of the alert email
$ALERT_EMAIL_SUBJ = 'Outage Detected!';		# Subject line of the 'station down' alert email
$OK_EMAIL_SUBJ = 'A-Ok!';			# Subject line of the 'station a-ok' alert email
$LIVE365_STATION_PORT = 80;			# port address of your Live365 server
$LIVE365_STATION_IP = "64.152.82.190";		# IP address of your Live365 server

# -----------------------
# SendAlert - Fire off a flare - send an alert email
#
sub SendAlert {
  if (!$opt_w) {
    print "$PGM_NAME: Sending alert email msg...\n"; }
  $smtp = new Mail::Sender
	{smtp=>$SMTP_SERVER,
	from=>$ALERT_EMAIL_ADDR,
	to=>$ALERT_EMAIL_ADDR,
	subject=>$ALERT_EMAIL_SUBJ};

  $smtp->Open();

  $smtp->SendLine("$errmsg\n");

  $smtp->Close;

  if (!$opt_w) {
    print "$PGM_NAME: Alert Msg sent.\n"; }
}

# -----------------------
# SendOk - Send a 'warm fuzzy - all is OK' msg
#
sub SendOk {
  if (!$opt_w) {
    print "$PGM_NAME: Sending OkeyDokey email msg...\n"; }
  $smtp = new Mail::Sender
	{smtp=>$SMTP_SERVER,
	from=>$ALERT_EMAIL_ADDR,
	to=>$ALERT_EMAIL_ADDR,
	subject=>$OK_EMAIL_SUBJ};

  $smtp->Open();

  $smtp->SendLine("All is well.\n");

  $smtp->Close;

  if (!$opt_w) {
    print "$PGM_NAME: Ok Msg sent.\n"; }
}

# ------------------------
# StationUp - Called if the stream is up
#
sub StationUp {
  if ($opt_w) {
    print "<font class='tiny' color='GREEN'>";
    print "Status: ONAIR";
    print "</font>";
  } else {
    print "$PGM_NAME: Status: ONAIR\n"; }

  if ($opt_a) {
    SendOk; }
}

# ------------------------
# StationDown - Called if the stream is down
#
sub StationDown {
  if ($opt_w) {
    print "<font color='RED'><b>";
    print "Status: OFFLINE.";
    print "</b></font>";
  } else {
    print "$PGM_NAME: Status: OFFLINE.\n"; }

  if ($opt_a) {
    SendAlert; }
}

# ------------------------
# Main 
#

  my $station_up = 0;		# Is the station up?

  getopts("awf:");		# a - Send Alert Email, w - HTML output, f - output filename

  $now = gmtime;
  if (!$opt_w) {
    print "$PGM_NAME: $PGM_VERS begins $now\n"; }	# display name, version and start time

  $t = new Net::Telnet (Timeout => 10,
                        Port => $LIVE365_STATION_PORT);	# Setup the connection to the stream

  $t->errmode("return");	# return to code, don't DIE on error;

  if ($opt_f) {			# open the output file, if any
    open(STDOUT, ">$opt_f"); }

  $errmsg = "*Err* Undetermined Error.";

  if ( $t->open($LIVE365_STATION_IP) )  {		# open the connection
  
    $t->print("HEAD / HTTP/1.0\n\n");			# send the request
    if (!$opt_w) {
      print "$PGM_NAME: --------- Response ---------\n"; }

    do {			# Check the response lines
      $line = $t->getline();
      if  (($line =~ m/200 OK/i) && (!$station_up) ) {	# goodness?
        $station_up = 1; }
      if (!$opt_w) {
        print "$PGM_NAME: $line"; }
    } while length $line > 1;

    $t->close;			# Be sure to close it, the 'cast will continue to send bits otherwise.

    if (!$opt_w) {
      print "$PGM_NAME: ============================\n"; }

  } else {			# Not able to establish connection
    $station_up = 0;
    $errtxt = $t->errmsg;
    $errmsg = "*Err* Unable to establish connection: $errtxt.";
    if (!$opt_w) { 
      print "$PGM_NAME: $errmsg\n"; }
  }

  if ($station_up) {
    StationUp;
  } else {
    StationDown; }

  if ($opt_f) {
     close(OUT); }

  select(STDOUT);
